@@ -160,6 +160,11 @@ c          regard it as neutron
          call cmkptc(knuc, -1, 0, pj)
          call ce2p(pj)
          symb = 'n'
+      elseif( pj.code == kbomega ) then
+c         very rare: regard it as proton
+         call cmkptc(knuc, -1, 1, pj)
+         call ce2p(pj)
+         symb = 'p'
       else
          write(0,*) 'code=',pj.code, ' charge=',pj.charge
          write(0,*) ' not supported in jam'
