@@ -218,7 +218,7 @@ c               call cresetTimer(MovedTrack)
 
       elseif(MoveStat .eq. ToBeObserved ) then
          ptclidx = MovedTrack.p.code  ! make 4 byte integer
-         ptclidx = min(ptclidx, 8)
+         ptclidx = min(ptclidx, 8)   ! this is only for using KEminObs
          if(MovedTrack.p.fm.p(4)-MovedTrack.p.mass 
      *        .ge. KEminObs(ptclidx) ) then    ! .gt. for <= uv6.00
 c             call only for high energy particles
@@ -489,6 +489,7 @@ c                  some work around for insufficient accuracy
                endif
             else
                leng = Infty
+               jcut = 0
             endif
          else
             leng = IntInfArray(i).length
@@ -505,6 +506,10 @@ c                  some work around for insufficient accuracy
             minlen = leng
          endif
       enddo
+c//////////////////
+c      write(0,*) ' pcor=',ProcessNo, ' leng=',minlen, ' Moves',
+c     *   MoveStat
+c/////////////
 
 c      if(leng .ge. minlen) then  !   bug in 6.00
 c      if(leng .ge. Infty) then  
@@ -550,7 +555,7 @@ c      write(0,*) ' after maxMovLen, leng=',leng, ' thick=',thick
 c      write(0,*) '  IntInfArray.length=',IntInfArray(ProcessNo).length
 c      write(0,*) ' procno=', ProcessNo, ' process=', 
 c     *   IntInfArray(ProcessNo).process
-c//////////
+cc//////////
       if(leng .lt. IntInfArray(ProcessNo).length ) then
          MoveStat = Truncated
          IntInfArray(ProcessNo).length = leng
